@@ -105,20 +105,21 @@ public class Tokenizer {
     }
     
     /**
-     * Returns the token pattern with the specified id.
+     * Returns a description of the token pattern with the specified 
+     * id.
      * 
      * @param id             the token pattern id
      * 
-     * @return the token pattern found, or
+     * @return the token pattern description, or
      *         null if not present
      */
-    public TokenPattern getPattern(int id) {
+    public String getPatternDescription(int id) {
         TokenMatcher  m;
         
         for (int i = 0; i < matchers.size(); i++) {
             m = (TokenMatcher) matchers.get(i);
             if (m.getPattern().getId() == id) {
-                return m.getPattern();
+                return m.getPattern().toShortString();
             }
         }
         return null;
